<?php

/*
 * 1. Install and Uninstall
 * 2. Enqueue Script and Styles
 * 3. Redirect after Activation
 */

/**
 * 1. Install and Unistall Process Starts
 */

global $bc_random_banner_db_version;
$bc_random_banner_db_version = BC_RB_PLUGIN_VERSION;

add_action('activate_' . BC_RB_PLUGIN_BASENAME, 'create_bc_random_banner_table');
/**
 * Create Random Banner Table
 */
function create_bc_random_banner_table()
{
  global $wpdb;
  global $bc_random_banner_db_version;
  $charset_collate = $wpdb->get_charset_collate();

  if (get_option('bc_random_banner_db_version'))
    return;

  $bc_random_banner = $wpdb->prefix . BC_RB_RANDOM_BANNER_DB;
  $bc_random_banner_options = $wpdb->prefix . BC_RB_RANDOM_BANNER_OPTION_DB;

  _bc_random_banner_table_create($bc_random_banner, $charset_collate);
  _bc_random_banner_option_table($bc_random_banner_options, $bc_random_banner, $charset_collate);

  add_option('bc_random_banner_db_version', $bc_random_banner_db_version);

  add_option('bc_rb_payment_info', 'no');
}


/**
 * Create Random Banner Option Table
 * @param $bc_random_banner_options
 * @param $bc_random_banner
 * @param $charset_collate
 */
function _bc_random_banner_option_table($bc_random_banner_options, $bc_random_banner, $charset_collate)
{
  require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
  $sql_create_table_bc_random_banner_options = "CREATE TABLE IF NOT EXISTS $bc_random_banner_options (
  id mediumint(9) NOT NULL AUTO_INCREMENT,
  country VARCHAR (255) NULL,
  ip_address VARCHAR (255) NULL,
  created_at VARCHAR (255) DEFAULT '0000-00-00 00:00:00' NOT NULL,
  random_banner_id mediumint(9) NOT NULL,
  PRIMARY KEY id (id),
  INDEX fk_statistics_random_banner_idx (random_banner_id ASC),
  CONSTRAINT fk_statistics_random_banner
    FOREIGN KEY (random_banner_id)
    REFERENCES {$bc_random_banner}(id)
    ON DELETE CASCADE ) $charset_collate; ";
  dbDelta($sql_create_table_bc_random_banner_options);
}

/**
 * Create Random Banner Table
 * @param $bc_random_banner
 * @param $charset_collate
 */
function _bc_random_banner_table_create($bc_random_banner, $charset_collate)
{
  require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
  $sql_create_table_bc_random_banner = "CREATE TABLE IF NOT EXISTS $bc_random_banner (
		id mediumint(9) NOT NULL AUTO_INCREMENT,
		file_url text NOT NULL,
		file_description varchar (255) NOT NULL,
		external_link text NOT NULL,
		banner_type varchar (255) NOT NULL,
		user_id mediumint(9) NOT NULL,
		created VARCHAR (255)  DEFAULT '0000-00-00 00:00:00' NOT NULL,
		PRIMARY KEY id (id)
	) $charset_collate;";

  dbDelta($sql_create_table_bc_random_banner);
}



/**
 * Uninstall DB and Files
 */
function uninstall_bc_random_banner_table()
{
  global $wpdb;
  $bc_random_banner_options = $wpdb->prefix . BC_RB_RANDOM_BANNER_OPTION_DB;
  $wpdb->query("DROP TABLE IF EXISTS $bc_random_banner_options");

  $bc_random_banner = $wpdb->prefix . BC_RB_RANDOM_BANNER_DB;
  $wpdb->query("DROP TABLE IF EXISTS $bc_random_banner");


  delete_option('bc_random_banner_db_version');
  delete_option('bc_rb_payment_info');
  delete_option('bc_rb_setting_options');
}

register_uninstall_hook(BC_RB_PLUGIN, 'uninstall_bc_random_banner_table');

/**
 * Install and Unistall Process Ends
 */


/**
 * 2. Script and Styles Starts
 */
add_action('admin_enqueue_scripts', 'bc_rb_enqueue');

/**
 * Conditional Enqueue Random Banner CSS and JS Files
 */
function bc_rb_enqueue()
{
  if (isset($_GET['page']) && ($_GET['page'] == 'bc_random_banner' || $_GET['page'] == 'bc_random_banner_support')
      || $_GET['page'] == 'bc_random_banner_option') {
    if (bc_rb_enqueue_script()) bc_rb_enqueue_script();
    if (bc_rb_enqueue_style()) bc_rb_enqueue_style();
  }

}

/**
* Update plugin if available
*/
add_action( 'admin_init', 'bc_rb_upgrade' );
function bc_rb_upgrade(){
  $old_version = get_option( 'bc_random_banner_db_version', '0' );
  $new_version = BC_RB_PLUGIN_VERSION;

  if ( $old_version == $new_version ) {
    return;
  }

  do_action( 'bc_rb_upgrade', $new_version, $old_version );

  update_option('bc_random_banner_db_version',$new_version);
}

/**
 * Enqueue all CSS Files
 */
function bc_rb_enqueue_style()
{

  wp_enqueue_style('bc_rb_style',
      plugins_url('assets/style/style.css', __FILE__),
      array(), BC_RB_PLUGIN_VERSION, 'all');

  if (!wp_style_is('bootstrap', 'enqueued')) {
    wp_enqueue_style('bootstrap',
        plugins_url('assets/style/bootstrap.css', __FILE__),
        array(), BC_RB_PLUGIN_VERSION, 'all');
  }

  if (!wp_style_is('sweetalert', 'enqueued')) {
    wp_enqueue_style('sweetalert',
        plugins_url('assets/style/sweetalert.css', __FILE__),
        array(), BC_RB_PLUGIN_VERSION, 'all');
  }


  do_action('bc_rb_enqueue_style');
}

/**
 * Enqueue all JS Files
 */
function bc_rb_enqueue_script()
{
  wp_enqueue_script('bc_rb_script',
      plugins_url('assets/script/script.js', __FILE__),
      array(), BC_RB_PLUGIN_VERSION, 'all');

  if (!wp_script_is('bootstrap', 'enqueued')) {
    wp_enqueue_script('bootstrap',
        plugins_url('assets/script/bootstrap.js', __FILE__),
        array(), BC_RB_PLUGIN_VERSION, 'all');
  }
  if (!wp_script_is('sweetalert', 'enqueued')) {
    wp_enqueue_script('sweetalert',
        plugins_url('assets/script/sweetalert.js', __FILE__),
        array(), BC_RB_PLUGIN_VERSION, 'all');
  }
  if (!wp_script_is('momentjs', 'enqueued')) {
    wp_enqueue_script('moment',
        plugins_url('assets/script/moment.js', __FILE__),
        array(), BC_RB_PLUGIN_VERSION, 'all');
  }

  // Pass PHP value to JavaScript
  $translation_array = array('plugin_url' => plugins_url(BC_RB_PLUGIN_NAME), 'payment_info' => get_option('bc_rb_payment_info'));
  wp_localize_script('bc_rb_script', 'vardata', $translation_array);

  wp_enqueue_media();
  do_action('bc_rb_enqueue_script');
}

/**
 * Script and Styles Ends
 */


/**
 * 3. Redirect on Activation starts
 */
register_activation_hook(BC_RB_PLUGIN, 'bc_rb_add_activation_option');
add_action('admin_init', 'bc_rb_activation_redirect');

/**
 * Redirect After Activation Hook
 */
function bc_rb_add_activation_option()
{
  add_option('bc_rb_activation_option_hook', true);
}

/**
 * Redirect After Activation
 */
function bc_rb_activation_redirect()
{
  if (get_option('bc_rb_activation_option_hook', false)) {
    delete_option('bc_rb_activation_option_hook');
    wp_redirect("admin.php?page=bc_random_banner");
  }
}

/**
 * 3. Redirect on Activation Ends
 */
